<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja">
<context>
    <name>AsciiFile</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="37"/>
        <location filename="../asciifile/asciifile.cpp" line="43"/>
        <source>Read ascii points</source>
        <translation>asciiポイントを読む</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="40"/>
        <source>Import ESRI Shapefile</source>
        <translation>ESRI Shapeのファイルをインポート</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <location filename="../align/align.cpp" line="20"/>
        <location filename="../align/align.cpp" line="27"/>
        <source>Align</source>
        <translation>整列</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="40"/>
        <source>first base point:</source>
        <translation>最初の基準点:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="42"/>
        <source>first target point:</source>
        <translation>最初の目標点:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="44"/>
        <source>second base point:</source>
        <translation>次の基準点:</translation>
    </message>
    <message>
        <location filename="../align/align.cpp" line="46"/>
        <source>second target point:</source>
        <translation>次の目標点:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <location filename="../list/list.cpp" line="23"/>
        <location filename="../list/list.cpp" line="30"/>
        <source>List entities</source>
        <translation>要素の一覧</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="46"/>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="60"/>
        <source>Empty Entity</source>
        <translation>要素はない</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="67"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="73"/>
        <source>Layer</source>
        <translation>レイヤー</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="75"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="76"/>
        <source>Line type</source>
        <translation>線の種類</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="77"/>
        <source>Line thickness</source>
        <translation>線の太さ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="78"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="84"/>
        <source>POINT</source>
        <translation>ポイント</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="85"/>
        <location filename="../list/list.cpp" line="195"/>
        <source>in point</source>
        <translation>頂点</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="90"/>
        <source>LINE</source>
        <translation>直線</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="95"/>
        <source>from point</source>
        <translation>始点</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="98"/>
        <source>to point</source>
        <translation>終点</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="103"/>
        <location filename="../list/list.cpp" line="127"/>
        <source>length</source>
        <translation>長さ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="108"/>
        <source>Angle in XY plane</source>
        <translation>傾きの角度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="109"/>
        <source>Inc.</source>
        <translation>始点、終点の距離</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="114"/>
        <source>ARC</source>
        <translation>弧</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="115"/>
        <location filename="../list/list.cpp" line="131"/>
        <location filename="../list/list.cpp" line="141"/>
        <source>center point</source>
        <translation>中心点</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="121"/>
        <location filename="../list/list.cpp" line="135"/>
        <location filename="../list/list.cpp" line="199"/>
        <source>radius</source>
        <translation>半径</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="122"/>
        <source>initial angle</source>
        <translation>始まりの角度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="123"/>
        <source>final angle</source>
        <translation>終わりの角度</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="130"/>
        <source>CIRCLE</source>
        <translation>円</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="136"/>
        <source>circumference</source>
        <translation>円周</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="137"/>
        <source>area</source>
        <translation>面積</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="140"/>
        <source>ELLIPSE</source>
        <translation>楕円</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="144"/>
        <source>major axis</source>
        <translation>主要な軸</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="162"/>
        <source>CONSTRUCTIONLINE</source>
        <translation>寸法補助線</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="165"/>
        <source>OVERLAYBOX</source>
        <translation>オーバーレイ・ボックス</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="168"/>
        <source>SOLID</source>
        <translation>平面</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="172"/>
        <source>MTEXT</source>
        <translation>マルチテキスト</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="175"/>
        <source>TEXT</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="178"/>
        <source>INSERT</source>
        <translation>挿入</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="181"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="182"/>
        <source>Insertion point</source>
        <translation>挿入位置</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="187"/>
        <source>POLYLINE</source>
        <translation>ポリライン</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="188"/>
        <source>Closed</source>
        <translation>閉じている</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>No</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="189"/>
        <source>Yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="190"/>
        <source>Vertices</source>
        <translation>頂点</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="204"/>
        <source>IMAGE</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="207"/>
        <source>SPLINE</source>
        <translation>スプライン</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="210"/>
        <source>SPLINEPOINTS</source>
        <translation>スプライン・ポイント</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="213"/>
        <source>HATCH</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="216"/>
        <source>DIMLEADER</source>
        <translation>寸法線（引き出し線）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="219"/>
        <source>DIMALIGNED</source>
        <translation>寸法線（２点間距離）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="222"/>
        <source>DIMLINEAR</source>
        <translation>寸法線（水平、垂直距離）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="225"/>
        <source>DIMRADIAL</source>
        <translation>寸法線（半径）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="228"/>
        <source>DIMDIAMETRIC</source>
        <translation>寸法線（直径）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="231"/>
        <source>DIMANGULAR</source>
        <translation>寸法線（角度）</translation>
    </message>
    <message>
        <location filename="../list/list.cpp" line="234"/>
        <source>UNKNOWN</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="21"/>
        <location filename="../sameprop/sameprop.cpp" line="28"/>
        <source>Same properties</source>
        <translation>線種の一致</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="41"/>
        <source>select original entity:</source>
        <translation>基準となる要素を選択:</translation>
    </message>
    <message>
        <location filename="../sameprop/sameprop.cpp" line="43"/>
        <source>select entities to change</source>
        <translation>変更する要素を選択</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <location filename="../sample/sample.cpp" line="26"/>
        <location filename="../sample/sample.cpp" line="33"/>
        <source>Sample plugin</source>
        <translation>プラグインのサンプル</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="38"/>
        <source>Read PIC file</source>
        <translation>PIC ファイルを読み込む</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="44"/>
        <source>import PIC file</source>
        <translation>PIC ファイルをインポート</translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="235"/>
        <source>Read ascii points</source>
        <translation>ascii ポイントを読む</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="241"/>
        <source>File...</source>
        <translation>ファイル...</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="248"/>
        <source>Format:</source>
        <translation>書式:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space Separator</source>
        <translation>空白で分割</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Tab Separator</source>
        <translation>タブで分割</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Comma Separator</source>
        <translation>カンマで分割</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>Space in Columns</source>
        <translation>空白行</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="250"/>
        <source>*.odb for Psion 2</source>
        <translation>Psion 2 の *.odb</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="252"/>
        <source>Connect points</source>
        <translation>ポイントを接続</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>2D Point</source>
        <translation>2D ポイント</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="260"/>
        <source>Draw 2D Point</source>
        <translation>2D ポイントを書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>3D Point</source>
        <translation>3D ポイント</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="261"/>
        <source>Draw 3D Point</source>
        <translation>３D ポイントを書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Point Number</source>
        <translation>ポイントの番号</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="262"/>
        <source>Draw point number</source>
        <translation>ポイント番号を書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Point Elevation</source>
        <translation>ポイントの上付き文字</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="263"/>
        <source>Draw point elevation</source>
        <translation>ポイントの上付き文字を書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Point Code</source>
        <translation>ポイント名</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="264"/>
        <source>Draw point code</source>
        <translation>ポイント名を書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="278"/>
        <source>Accept</source>
        <translation>書く</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="283"/>
        <source>Cancel</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="313"/>
        <source>Select file</source>
        <translation>ファイルの選択</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="320"/>
        <source>Point 2D layer is empty</source>
        <translation>２D ポイントのレイヤー指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="323"/>
        <source>Point 3D layer is empty</source>
        <translation>3D ポイントのレイヤー指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="326"/>
        <source>Point elevation layer is empty</source>
        <translation>ポイントの上付きのレイヤー指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="327"/>
        <source>Point elevation height is empty</source>
        <translation>ポイントの上付きの文字の高さ指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="328"/>
        <source>Point elevation separation is empty</source>
        <translation>ポイントの上付きの隙間の指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="331"/>
        <source>Point number layer is empty</source>
        <translation>ポイント番号のレイヤー指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="332"/>
        <source>Point number height is empty</source>
        <translation>ポイント番号の文字の高さ指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="333"/>
        <source>Point number separation is empty</source>
        <translation>ポイント番号の隙間の指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="336"/>
        <source>Point code layer is empty</source>
        <translation>ポイント名のレイヤー指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="337"/>
        <source>Point code height is empty</source>
        <translation>ポイント名の文字の高さ指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="338"/>
        <source>Point code separation is empty</source>
        <translation>ポイント名の隙間の指定が未入力です</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="366"/>
        <source>The file %1 not exist</source>
        <translation>ファイル %1 は存在しない</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="371"/>
        <source>Can&apos;t open the file %1</source>
        <translation>ファイル %1 は開くことができない</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <location filename="../importshp/importshp.cpp" line="59"/>
        <source>File...</source>
        <translation>ファイル...</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="67"/>
        <source>File type:</source>
        <translation>ファイルの種類:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="75"/>
        <source>Layer</source>
        <translation>レイヤー</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="56"/>
        <source>Import ESRI Shapefile</source>
        <translation>ESRI Shapeのファイルをインポート</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="68"/>
        <location filename="../importshp/importshp.cpp" line="266"/>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="76"/>
        <location filename="../importshp/importshp.cpp" line="89"/>
        <location filename="../importshp/importshp.cpp" line="102"/>
        <location filename="../importshp/importshp.cpp" line="115"/>
        <source>Current</source>
        <translation>現在のもので</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="77"/>
        <location filename="../importshp/importshp.cpp" line="90"/>
        <location filename="../importshp/importshp.cpp" line="103"/>
        <location filename="../importshp/importshp.cpp" line="116"/>
        <source>From data:</source>
        <translation>データーから:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="88"/>
        <source>Color</source>
        <translation>色</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="101"/>
        <source>Line type</source>
        <translation>線の種類</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="114"/>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="127"/>
        <location filename="../importshp/importshp.cpp" line="213"/>
        <source>Point</source>
        <translation>ポイント</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="128"/>
        <source>as Point</source>
        <translation>現在のポイント</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="129"/>
        <source>as Label:</source>
        <translation>ラベルによる:</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="141"/>
        <source>Accept</source>
        <translation>読み込む</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="142"/>
        <source>Cancel</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="167"/>
        <source>Select file</source>
        <translation>ファイル選択</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="217"/>
        <source>Point+Measure</source>
        <translation>ポイント＋巻尺</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="221"/>
        <source>3D Point</source>
        <translation>３D ポイント</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="225"/>
        <source>Multi Point</source>
        <translation>マルチ・ポイント</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="229"/>
        <source>Multi Point+Measure</source>
        <translation>マルチ・ポイント＋巻尺</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="233"/>
        <source>3D Multi Point</source>
        <translation>３D マルチ・ポイント</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="237"/>
        <source>Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="241"/>
        <source>Arc+Measure</source>
        <translation>弧＋巻尺</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="245"/>
        <source>3D Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="249"/>
        <source>Polygon</source>
        <translation>ポリゴン</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="253"/>
        <source>Polygon+Measure</source>
        <translation>ポリゴン＋巻尺</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="257"/>
        <source>3D Polygon</source>
        <translation>３D ポリゴン</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="261"/>
        <source>Multipatch</source>
        <translation>マルチ・パッチ</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="281"/>
        <source>The file %1 not have extension .shp</source>
        <translation>ファイル %1 は拡張子 .shp を持っていない</translation>
    </message>
    <message>
        <location filename="../importshp/importshp.cpp" line="286"/>
        <source>The file %1 not exist</source>
        <translation>ファイル %1 は存在しない</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <location filename="../list/list.cpp" line="251"/>
        <source>List entities</source>
        <translation>要素一覧</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <location filename="../sample/sample.cpp" line="54"/>
        <source>Draw line</source>
        <translation>線を書く</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="60"/>
        <source>Start X:</source>
        <translation>始点 X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="66"/>
        <source>Start Y:</source>
        <translation>始点 Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="72"/>
        <source>End X:</source>
        <translation>終点 X:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="78"/>
        <source>End Y:</source>
        <translation>終点 Y:</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="86"/>
        <source>Accept</source>
        <translation>書く</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="91"/>
        <source>Cancel</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="107"/>
        <source>Start X is empty</source>
        <translation>始点 X は空です</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="108"/>
        <source>Start Y is empty</source>
        <translation>始点 Y は空です</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="109"/>
        <source>End X is empty</source>
        <translation>終点 X は空です</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="110"/>
        <source>End Y is empty</source>
        <translation>終点 Y は空です</translation>
    </message>
    <message>
        <location filename="../sample/sample.cpp" line="132"/>
        <source>Sample plugin</source>
        <translation>プラグイン・サンブル</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <location filename="../picfile/picfile.cpp" line="67"/>
        <source>File...</source>
        <translation>ファイル...</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="77"/>
        <source>Scale:</source>
        <translation>縮尺:</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="81"/>
        <source>Accept</source>
        <translation>書く</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="85"/>
        <source>Cancel</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="113"/>
        <source>Select file</source>
        <translation>ファイル選択</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="121"/>
        <source>Scale Factor is empty or invalid</source>
        <translation>縮尺が未記入か無効</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="134"/>
        <source>The file %1 not exist</source>
        <translation>ファイル %1 は存在しない</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="139"/>
        <source>Can&apos;t open the file %1</source>
        <translation>ファイル %1 は開くことができない</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="146"/>
        <source>%1 objects imported</source>
        <translation>オブジェクト %1 はインポートされた</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="168"/>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation>picPunto 線を引く: 最初のポイントが未記入 %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="181"/>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation>picPunto 線を引く: 次のポイントが未記入 %1</translation>
    </message>
    <message>
        <location filename="../picfile/picfile.cpp" line="260"/>
        <location filename="../picfile/picfile.cpp" line="269"/>
        <source>format error in %1</source>
        <translation>%1 で書式エラー</translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <location filename="../plotequation/plot.cpp" line="21"/>
        <location filename="../plotequation/plot.cpp" line="28"/>
        <source>Plot plugin</source>
        <translation>式を入力して書くためのプラグイン</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="obsolete">書く</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="15"/>
        <source>Plot equation</source>
        <translation>式を入力して線を引く</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="18"/>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation>このプラグインは、あなたが式を入力して書くことを可能にします。
もし、パラメータを使いたくなければ、「式 2」は除外してください。
円周率が必要な時には、例のように書くことで円周率を使えます。（例（3*pi））
式において変数／パラメータには、 t または x を使うこと。</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="22"/>
        <source>Equation 1:</source>
        <translation>式 1:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="23"/>
        <source>Equation 2:</source>
        <translation>式 2:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="26"/>
        <source>start value:</source>
        <translation>初めの値：</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="27"/>
        <source>end value:</source>
        <translation>終わりの値:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="28"/>
        <source>step size:</source>
        <translation>スキップの値:</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="32"/>
        <source>Draw</source>
        <translation>書く</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="33"/>
        <source>Cancel</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="59"/>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation>線の区切り</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="60"/>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation>ポリライン</translation>
    </message>
    <message>
        <location filename="../plotequation/plotdialog.cpp" line="61"/>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation>スプライン・ポイント</translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="177"/>
        <source>Layer:</source>
        <translation>レイヤー:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="210"/>
        <source>Style:</source>
        <translation>スタイル:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="211"/>
        <source>Height:</source>
        <translation>文字の高さ:</translation>
    </message>
    <message>
        <location filename="../asciifile/asciifile.cpp" line="212"/>
        <source>Separation</source>
        <translation>隙間の大きさ</translation>
    </message>
</context>
</TS>
